==> OpenJDK-1.7.0.9-x86_64-bin.tar.xz: sun/awt/resources/awt_pt_BR.java <==
package sun.awt.resources;

import java.util.ListResourceBundle;

public final class awt_pt_BR extends ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "AWT.CompositionWindowTitle", "Janela de Entrada" },
            { "AWT.CrosshairCursor", "Cursor em Forma de Cruz" },
            { "AWT.DefaultCursor", "Cursor Default" },
            { "AWT.DefaultDragCursor", "Cursor Default de Arrastar" },
            { "AWT.DefaultDropCursor", "Cursor Default de Soltar" },
            { "AWT.DefaultNoDropCursor", "Cursor Default sem Arrastar" },
            { "AWT.EResizeCursor", "Cursor de Seta Que Aponta \u00E0 Direita" },
            { "AWT.HandCursor", "Cursor em Forma de M\u00E3o" },
            { "AWT.HostInputMethodDisplayName", "M\u00E9todos de Entrada do Sistema" },
            { "AWT.InconsistentDLLsWarning", "Pode ser que as opera\u00E7\u00F5es baseadas em texto n\u00E3o funcionem corretamente devido a um conjunto incoerente de bibliotecas de vincula\u00E7\u00E3o din\u00E2mica (DLLs) instalado no seu sistema. Para obter mais informa\u00E7\u00F5es sobre este problema e uma solu\u00E7\u00E3o recomendada, consulte as Notas de Vers\u00E3o do Java(TM) 2 SDK, Standard Edition, em java.sun.com." },
            { "AWT.InputMethodCreationFailed", "N\u00E3o foi poss\u00EDvel criar {0}. Motivo: {1}" },
            { "AWT.InputMethodLanguage.ja", "Japon\u00EAs" },
            { "AWT.InputMethodLanguage.ko", "Coreano" },
            { "AWT.InputMethodLanguage.zh", "Chin\u00EAs" },
            { "AWT.InputMethodLanguage.zh_CN", "Chin\u00EAs Simplificado" },
            { "AWT.InputMethodLanguage.zh_TW", "Chin\u00EAs Tradicional" },
            { "AWT.InputMethodSelectionMenu", "Selecionar M\u00E9todo de Entrada" },
            { "AWT.Less", "Menos" },
            { "AWT.MoveCursor", "Cursor de Movimento" },
            { "AWT.NEResizeCursor", "Cursor de Seta Que Aponta para Nordeste" },
            { "AWT.NResizeCursor", "Cursor de Seta Que Aponta para Cima" },
            { "AWT.NWResizeCursor", "Cursor de Seta Que Aponta para Noroeste" },
            { "AWT.SEResizeCursor", "Cursor de Seta Que Aponta para Sudeste" },
            { "AWT.SResizeCursor", "Cursor de Seta Que Aponta para Baixo" },
            { "AWT.SWResizeCursor", "Cursor de Seta Que Aponta para Sudoeste" },
            { "AWT.TextCursor", "Cursor de Texto" },
            { "AWT.WResizeCursor", "Cursor de Seta Que Aponta \u00E0 Esquerda" },
            { "AWT.WaitCursor", "Cursor em Forma de Ampulheta" },
            { "AWT.accept", "Aceitar" },
            { "AWT.add", "Teclado Num\u00E9rico +" },
            { "AWT.again", "Novamente" },
            { "AWT.allCandidates", "Todos os Candidatos" },
            { "AWT.alphanumeric", "Alfanum\u00E9rico" },
            { "AWT.alt", "Alt" },
            { "AWT.altGraph", "Alt Graph" },
            { "AWT.ampersand", "E Comercial" },
            { "AWT.asterisk", "Asterisco" },
            { "AWT.at", "Arroba" },
            { "AWT.backQuote", "Crase" },
            { "AWT.backSlash", "Barra Invertida" },
            { "AWT.backSpace", "Backspace" },
            { "AWT.begin", "Come\u00E7ar" },
            { "AWT.braceLeft", "Chave Esquerda" },
            { "AWT.braceRight", "Chave Direta" },
            { "AWT.cancel", "Cancelar" },
            { "AWT.capsLock", "Caps Lock" },
            { "AWT.circumflex", "Circunflexo" },
            { "AWT.clear", "Limpar" },
            { "AWT.closeBracket", "Par\u00EAntese de Fechamento" },
            { "AWT.codeInput", "Entrada de C\u00F3digo" },
            { "AWT.colon", "V\u00EDrgula" },
            { "AWT.comma", "V\u00EDrgula" },
            { "AWT.compose", "Compor" },
            { "AWT.context", "Menu de Contexto" },
            { "AWT.control", "Ctrl" },
            { "AWT.convert", "Converter" },
            { "AWT.copy", "Copiar" },
            { "AWT.cut", "Recortar" },
            { "AWT.deadAboveDot", "Ponto em Cima" },
            { "AWT.deadAboveRing", "S\u00EDmbolo de Grau" },
            { "AWT.deadAcute", "Acento Agudo" },
            { "AWT.deadBreve", "Braquia" },
            { "AWT.deadCaron", "Acento Circunflexo Invertido" },
            { "AWT.deadCedilla", "Cedilha" },
            { "AWT.deadCircumflex", "Acento Circunflexo" },
            { "AWT.deadDiaeresis", "Trema" },
            { "AWT.deadDoubleAcute", "Acento Agudo Duplo" },
            { "AWT.deadGrave", "Acento Grave" },
            { "AWT.deadIota", "Lota" },
            { "AWT.deadMacron", "M\u00E1cron" },
            { "AWT.deadOgonek", "Gancho Polon\u00EAs" },
            { "AWT.deadSemivoicedSound", "Surdo (Som)" },
            { "AWT.deadTilde", "Til" },
            { "AWT.deadVoicedSound", "Sonoro (Som)" },
            { "AWT.decimal", "Teclado Num\u00E9rico ." },
            { "AWT.delete", "Deletar" },
            { "AWT.divide", "Teclado Num\u00E9rico /" },
            { "AWT.dollar", "D\u00F3lar" },
            { "AWT.down", "Abaixo" },
            { "AWT.end", "Fim" },
            { "AWT.enter", "Enter" },
            { "AWT.equals", "Igual" },
            { "AWT.escape", "Escape" },
            { "AWT.euro", "Euro" },
            { "AWT.exclamationMark", "Ponto de Exclama\u00E7\u00E3o" },
            { "AWT.f1", "F1" },
            { "AWT.f10", "F10" },
            { "AWT.f11", "F11" },
            { "AWT.f12", "F12" },
            { "AWT.f13", "F13" },
            { "AWT.f14", "F14" },
            { "AWT.f15", "F15" },
            { "AWT.f16", "F16" },
            { "AWT.f17", "F17" },
            { "AWT.f18", "F18" },
            { "AWT.f19", "F19" },
            { "AWT.f2", "F2" },
            { "AWT.f20", "F20" },
            { "AWT.f21", "F21" },
            { "AWT.f22", "F22" },
            { "AWT.f23", "F23" },
            { "AWT.f24", "F24" },
            { "AWT.f3", "F3" },
            { "AWT.f4", "F4" },
            { "AWT.f5", "F5" },
            { "AWT.f6", "F6" },
            { "AWT.f7", "F7" },
            { "AWT.f8", "F8" },
            { "AWT.f9", "F9" },
            { "AWT.final", "Final" },
            { "AWT.find", "Localizar" },
            { "AWT.fullWidth", "Largura Total" },
            { "AWT.greater", "Maior" },
            { "AWT.halfWidth", "Meia Largura" },
            { "AWT.help", "Ajuda" },
            { "AWT.hiragana", "Hiragana" },
            { "AWT.home", "In\u00EDcio" },
            { "AWT.inputMethodOnOff", "M\u00E9todo de Entrada Ativado/Desativado" },
            { "AWT.insert", "Insert" },
            { "AWT.invertedExclamationMark", "Ponto de Exclama\u00E7\u00E3o Invertido" },
            { "AWT.japaneseHiragana", "Hiragana Japon\u00EAs" },
            { "AWT.japaneseKatakana", "Katakana Japon\u00EAs" },
            { "AWT.japaneseRoman", "Romano Japon\u00EAs" },
            { "AWT.kana", "Kana" },
            { "AWT.kanaLock", "Kana Lock" },
            { "AWT.kanji", "Kanji" },
            { "AWT.katakana", "Katakana" },
            { "AWT.left", "Esquerda" },
            { "AWT.leftParenthesis", "Par\u00EAntese Esquerdo" },
            { "AWT.meta", "Meta" },
            { "AWT.minus", "Menos" },
            { "AWT.modechange", "Altera\u00E7\u00E3o de Modo" },
            { "AWT.multiply", "Teclado Num\u00E9rico *" },
            { "AWT.noconvert", "N\u00E3o Converter" },
            { "AWT.numLock", "Num Lock" },
            { "AWT.numberSign", "Sinal Num\u00E9rico" },
            { "AWT.numpad", "Teclado Num\u00E9rico" },
            { "AWT.openBracket", "Par\u00EAntese de Abertura" },
            { "AWT.paste", "Colar" },
            { "AWT.pause", "Pausar" },
            { "AWT.period", "Ponto Final" },
            { "AWT.pgdn", "P\u00E1gina Abaixo" },
            { "AWT.pgup", "P\u00E1gina Acima" },
            { "AWT.plus", "Mais" },
            { "AWT.previousCandidate", "Candidato Anterior" },
            { "AWT.printScreen", "Print Screen" },
            { "AWT.props", "Sustentar" },
            { "AWT.quote", "Aspas" },
            { "AWT.quoteDbl", "Aspas Duplas" },
            { "AWT.right", "Direita" },
            { "AWT.rightParenthesis", "Par\u00EAntese Direito" },
            { "AWT.romanCharacters", "Caracteres Romanos" },
            { "AWT.scrollLock", "Scroll Lock" },
            { "AWT.semicolon", "Ponto-e-V\u00EDrgula" },
            { "AWT.separater", "Teclado Num\u00E9rico ," },
            { "AWT.separator", "Teclado Num\u00E9rico ," },
            { "AWT.shift", "Shift" },
            { "AWT.slash", "Barra" },
            { "AWT.space", "Espa\u00E7o" },
            { "AWT.stop", "Interromper" },
            { "AWT.subtract", "Teclado Num\u00E9rico -" },
            { "AWT.tab", "Guia" },
            { "AWT.undefined", "Indefinido" },
            { "AWT.underscore", "Sublinhado" },
            { "AWT.undo", "Desfazer" },
            { "AWT.unknown", "Desconhecido" },
            { "AWT.up", "Acima" },
            { "AWT.windows", "Janelas" },
            { "java.awt.def.delay", "30" },
            { "java.awt.im.style", "no momento" },
        };
    }
}

==> OpenJDK-1.7.0.60-x86_64-bin.tar.xz: sun/awt/resources/awt_pt_BR.java <==
package sun.awt.resources;

import java.util.ListResourceBundle;

public final class awt_pt_BR extends ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "AWT.CompositionWindowTitle", "Janela de Entrada" },
            { "AWT.CrosshairCursor", "Cursor em Forma de Cruz" },
            { "AWT.DefaultCursor", "Cursor Padr\u00E3o" },
            { "AWT.DefaultDragCursor", "Cursor Padr\u00E3o de Arrastar" },
            { "AWT.DefaultDropCursor", "Cursor Padr\u00E3o de Soltar" },
            { "AWT.DefaultNoDropCursor", "Cursor Padr\u00E3o sem Arrastar" },
            { "AWT.EResizeCursor", "Cursor de Seta Que Aponta \u00E0 Direita" },
            { "AWT.HandCursor", "Cursor em Forma de M\u00E3o" },
            { "AWT.HostInputMethodDisplayName", "M\u00E9todos de Entrada do Sistema" },
            { "AWT.InconsistentDLLsWarning", "Pode ser que as opera\u00E7\u00F5es baseadas em texto n\u00E3o funcionem corretamente devido a um conjunto incoerente de bibliotecas de vincula\u00E7\u00E3o din\u00E2mica (DLLs) instalado no seu sistema. Para obter mais informa\u00E7\u00F5es sobre este problema e uma solu\u00E7\u00E3o recomendada, consulte as Notas de Vers\u00E3o do Java(TM) 2 SDK, Standard Edition, em java.sun.com." },
            { "AWT.InputMethodCreationFailed", "N\u00E3o foi poss\u00EDvel criar {0}. Motivo: {1}" },
            { "AWT.InputMethodLanguage.ja", "Japon\u00EAs" },
            { "AWT.InputMethodLanguage.ko", "Coreano" },
            { "AWT.InputMethodLanguage.zh", "Chin\u00EAs" },
            { "AWT.InputMethodLanguage.zh_CN", "Chin\u00EAs Simplificado" },
            { "AWT.InputMethodLanguage.zh_TW", "Chin\u00EAs Tradicional" },
            { "AWT.InputMethodSelectionMenu", "Selecionar M\u00E9todo de Entrada" },
            { "AWT.Less", "Menos" },
            { "AWT.MoveCursor", "Cursor de Movimento" },
            { "AWT.NEResizeCursor", "Cursor de Seta Que Aponta para Nordeste" },
            { "AWT.NResizeCursor", "Cursor de Seta Que Aponta para Cima" },
            { "AWT.NWResizeCursor", "Cursor de Seta Que Aponta para Noroeste" },
            { "AWT.SEResizeCursor", "Cursor de Seta Que Aponta para Sudeste" },
            { "AWT.SResizeCursor", "Cursor de Seta Que Aponta para Baixo" },
            { "AWT.SWResizeCursor", "Cursor de Seta Que Aponta para Sudoeste" },
            { "AWT.TextCursor", "Cursor de Texto" },
            { "AWT.WResizeCursor", "Cursor de Seta Que Aponta \u00E0 Esquerda" },
            { "AWT.WaitCursor", "Cursor em Forma de Ampulheta" },
            { "AWT.accept", "Aceitar" },
            { "AWT.add", "Teclado Num\u00E9rico +" },
            { "AWT.again", "Novamente" },
            { "AWT.allCandidates", "Todos os Candidatos" },
            { "AWT.alphanumeric", "Alfanum\u00E9rico" },
            { "AWT.alt", "Alt" },
            { "AWT.altGraph", "Alt Graph" },
            { "AWT.ampersand", "E Comercial" },
            { "AWT.asterisk", "Asterisco" },
            { "AWT.at", "Arroba" },
            { "AWT.backQuote", "Crase" },
            { "AWT.backSlash", "Barra Invertida" },
            { "AWT.backSpace", "Backspace" },
            { "AWT.begin", "Come\u00E7ar" },
            { "AWT.braceLeft", "Chave Esquerda" },
            { "AWT.braceRight", "Chave Direta" },
            { "AWT.cancel", "Cancelar" },
            { "AWT.capsLock", "Caps Lock" },
            { "AWT.circumflex", "Circunflexo" },
            { "AWT.clear", "Limpar" },
            { "AWT.closeBracket", "Par\u00EAntese de Fechamento" },
            { "AWT.codeInput", "Entrada de C\u00F3digo" },
            { "AWT.colon", "V\u00EDrgula" },
            { "AWT.comma", "V\u00EDrgula" },
            { "AWT.compose", "Compor" },
            { "AWT.context", "Menu de Contexto" },
            { "AWT.control", "Ctrl" },
            { "AWT.convert", "Converter" },
            { "AWT.copy", "Copiar" },
            { "AWT.cut", "Recortar" },
            { "AWT.deadAboveDot", "Ponto em Cima" },
            { "AWT.deadAboveRing", "S\u00EDmbolo de Grau" },
            { "AWT.deadAcute", "Acento Agudo" },
            { "AWT.deadBreve", "Braquia" },
            { "AWT.deadCaron", "Acento Circunflexo Invertido" },
            { "AWT.deadCedilla", "Cedilha" },
            { "AWT.deadCircumflex", "Acento Circunflexo" },
            { "AWT.deadDiaeresis", "Trema" },
            { "AWT.deadDoubleAcute", "Acento Agudo Duplo" },
            { "AWT.deadGrave", "Acento Grave" },
            { "AWT.deadIota", "Lota" },
            { "AWT.deadMacron", "M\u00E1cron" },
            { "AWT.deadOgonek", "Gancho Polon\u00EAs" },
            { "AWT.deadSemivoicedSound", "Surdo (Som)" },
            { "AWT.deadTilde", "Til" },
            { "AWT.deadVoicedSound", "Sonoro (Som)" },
            { "AWT.decimal", "Teclado Num\u00E9rico ." },
            { "AWT.delete", "Deletar" },
            { "AWT.divide", "Teclado Num\u00E9rico /" },
            { "AWT.dollar", "D\u00F3lar" },
            { "AWT.down", "Abaixo" },
            { "AWT.end", "Fim" },
            { "AWT.enter", "Enter" },
            { "AWT.equals", "Igual" },
            { "AWT.escape", "Escape" },
            { "AWT.euro", "Euro" },
            { "AWT.exclamationMark", "Ponto de Exclama\u00E7\u00E3o" },
            { "AWT.f1", "F1" },
            { "AWT.f10", "F10" },
            { "AWT.f11", "F11" },
            { "AWT.f12", "F12" },
            { "AWT.f13", "F13" },
            { "AWT.f14", "F14" },
            { "AWT.f15", "F15" },
            { "AWT.f16", "F16" },
            { "AWT.f17", "F17" },
            { "AWT.f18", "F18" },
            { "AWT.f19", "F19" },
            { "AWT.f2", "F2" },
            { "AWT.f20", "F20" },
            { "AWT.f21", "F21" },
            { "AWT.f22", "F22" },
            { "AWT.f23", "F23" },
            { "AWT.f24", "F24" },
            { "AWT.f3", "F3" },
            { "AWT.f4", "F4" },
            { "AWT.f5", "F5" },
            { "AWT.f6", "F6" },
            { "AWT.f7", "F7" },
            { "AWT.f8", "F8" },
            { "AWT.f9", "F9" },
            { "AWT.final", "Final" },
            { "AWT.find", "Localizar" },
            { "AWT.fullWidth", "Largura Total" },
            { "AWT.greater", "Maior" },
            { "AWT.halfWidth", "Meia Largura" },
            { "AWT.help", "Ajuda" },
            { "AWT.hiragana", "Hiragana" },
            { "AWT.home", "In\u00EDcio" },
            { "AWT.inputMethodOnOff", "M\u00E9todo de Entrada Ativado/Desativado" },
            { "AWT.insert", "Insert" },
            { "AWT.invertedExclamationMark", "Ponto de Exclama\u00E7\u00E3o Invertido" },
            { "AWT.japaneseHiragana", "Hiragana Japon\u00EAs" },
            { "AWT.japaneseKatakana", "Katakana Japon\u00EAs" },
            { "AWT.japaneseRoman", "Romano Japon\u00EAs" },
            { "AWT.kana", "Kana" },
            { "AWT.kanaLock", "Kana Lock" },
            { "AWT.kanji", "Kanji" },
            { "AWT.katakana", "Katakana" },
            { "AWT.left", "Esquerda" },
            { "AWT.leftParenthesis", "Par\u00EAntese Esquerdo" },
            { "AWT.meta", "Meta" },
            { "AWT.minus", "Menos" },
            { "AWT.modechange", "Altera\u00E7\u00E3o de Modo" },
            { "AWT.multiply", "Teclado Num\u00E9rico *" },
            { "AWT.noconvert", "N\u00E3o Converter" },
            { "AWT.numLock", "Num Lock" },
            { "AWT.numberSign", "Sinal Num\u00E9rico" },
            { "AWT.numpad", "Teclado Num\u00E9rico" },
            { "AWT.openBracket", "Par\u00EAntese de Abertura" },
            { "AWT.paste", "Colar" },
            { "AWT.pause", "Pausar" },
            { "AWT.period", "Ponto Final" },
            { "AWT.pgdn", "P\u00E1gina Abaixo" },
            { "AWT.pgup", "P\u00E1gina Acima" },
            { "AWT.plus", "Mais" },
            { "AWT.previousCandidate", "Candidato Anterior" },
            { "AWT.printScreen", "Print Screen" },
            { "AWT.props", "Sustentar" },
            { "AWT.quote", "Aspas" },
            { "AWT.quoteDbl", "Aspas Duplas" },
            { "AWT.right", "Direita" },
            { "AWT.rightParenthesis", "Par\u00EAntese Direito" },
            { "AWT.romanCharacters", "Caracteres Romanos" },
            { "AWT.scrollLock", "Scroll Lock" },
            { "AWT.semicolon", "Ponto-e-V\u00EDrgula" },
            { "AWT.separater", "Teclado Num\u00E9rico ," },
            { "AWT.separator", "Teclado Num\u00E9rico ," },
            { "AWT.shift", "Shift" },
            { "AWT.slash", "Barra" },
            { "AWT.space", "Espa\u00E7o" },
            { "AWT.stop", "Interromper" },
            { "AWT.subtract", "Teclado Num\u00E9rico -" },
            { "AWT.tab", "Guia" },
            { "AWT.undefined", "Indefinido" },
            { "AWT.underscore", "Sublinhado" },
            { "AWT.undo", "Desfazer" },
            { "AWT.unknown", "Desconhecido" },
            { "AWT.up", "Acima" },
            { "AWT.windows", "Janelas" },
            { "java.awt.def.delay", "30" },
            { "java.awt.im.style", "no momento" },
        };
    }
}
